<?php

require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'lsicool_setup_theme' );
add_action( 'after_setup_theme', 'lsicool_load_default_hooks' );


function lsicool_setup_theme() {

	load_theme_textdomain( 'lsicool', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'editor-styles' );
    
	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	/*---------- Register image sizes ----------*/
	
	//Register image sizes
	add_image_size( 'lsicool_270x429', 270, 429, true ); //lsicool_270x429 Gallery V1
	add_image_size( 'lsicool_89x89', 89, 89, true ); //lsicool_89x89 Testimonials V1
	add_image_size( 'lsicool_370x359', 370, 359, true ); //lsicool_370x359 Latest News
	add_image_size( 'lsicool_368x251', 368, 251, true ); //lsicool_368x251 Our Services V1
	add_image_size( 'lsicool_202x226', 202, 226, true ); //lsicool_202x226 Gallery V2
	add_image_size( 'lsicool_370x422', 370, 422, true ); //lsicool_370x422 Gallery V3
	add_image_size( 'lsicool_370x502', 370, 502, true ); //lsicool_370x502 Gallery V4
	add_image_size( 'lsicool_300x476', 300, 476, true ); //lsicool_300x476 Gallery V5
	add_image_size( 'lsicool_570x355', 570, 355, true ); //lsicool_570x355 Latest News V2
	add_image_size( 'lsicool_270x161', 270, 161, true ); //lsicool_270x161 Latest News V2
	add_image_size( 'lsicool_770x415', 770, 415, true ); //lsicool_770x415 Archive Page
	add_image_size( 'lsicool_1170x415', 1170, 415, true ); //lsicool_1170x415 Blog Detail Page
	
	/*---------- Register image sizes ends ----------*/
	
	
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'lsicool' ),
		'onepage_menu' => esc_html__( 'OnePage Menu', 'lsicool' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'lsicool_admin_init', 2000000 );
}

/**
 * [lsicool_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */


function lsicool_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/*---------- Sidebar settings ----------*/

/**
 * [lsicool_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function lsicool_widgets_init() {

	global $wp_registered_sidebars;

	$theme_options = get_theme_mod( 'lsicool' . '_options-mods' );
	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'lsicool' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'lsicool' ),
		'before_widget' => '<div id="%1$s" class="widget sidebar-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar__title"><h3>',
		'after_title'   => '</h3></div>',
	) );
	if ( class_exists( '\Elementor\Plugin' )){
	register_sidebar(array(
	  'name' => esc_html__( 'Blog Listing', 'lsicool' ),
	  'id' => 'blog-sidebar',
	  'description' => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'lsicool' ),
	  'before_widget'=>'<div id="%1$s" class="widget sidebar-widget %2$s">',
	  'after_widget'=>'</div>',
	  'before_title' => '<div class="sidebar__title"><h3>',
	  'after_title' => '</h3></div>'
	));
	}
	if ( ! is_object( lsicool_WSH() ) ) {
		return;
	}

	$sidebars = lsicool_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( lsicool_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'before_widget' => '<div id="%1$s" class="%2$s widget sidebar-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h2>',
			'after_title'   => '</h2></div>',
		));
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'lsicool_widgets_init' );

/*---------- Sidebar settings ends ----------*/

/*---------- Gutenberg settings ----------*/

function lsicool_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'lsicool' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'lsicool' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'lsicool' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'lsicool' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'lsicool' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'lsicool' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'lsicool' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'lsicool' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'lsicool' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'lsicool_gutenberg_editor_palette_styles' );

/*---------- Gutenberg settings ends ----------*/

/*---------- Enqueue Styles and Scripts ----------*/

function lsicool_enqueue_scripts() {
	$options = lsicool_WSH()->option();
	
    //styles


	wp_enqueue_style( 'animate-min', get_template_directory_uri() . '/assets/vendors/animate/animate.min.css' );
    wp_enqueue_style( 'custom-animate', get_template_directory_uri() . '/assets/vendors/animate/custom-animate.css' );
    wp_enqueue_style( 'bootstrap-min', get_template_directory_uri() . '/assets/vendors/bootstrap/css/bootstrap.min.css' );
    wp_enqueue_style( 'bootstrap-select-min', get_template_directory_uri() . '/assets/vendors/bootstrap-select/css/bootstrap-select.min.css' );
    wp_enqueue_style( 'bxslider-css', get_template_directory_uri() . '/assets/vendors/bxslider/jquery.bxslider.css' );
    wp_enqueue_style( 'fontawesome-all-min', get_template_directory_uri() . '/assets/vendors/fontawesome/css/all.min.css' );
    wp_enqueue_style( 'magnific-popup-css', get_template_directory_uri() . '/assets/vendors/jquery-magnific-popup/jquery.magnific-popup.css' );
    wp_enqueue_style( 'jquery-ui-css', get_template_directory_uri() . '/assets/vendors/jquery-ui/jquery-ui.css' );
    wp_enqueue_style( 'nice-select-css', get_template_directory_uri() . '/assets/vendors/nice-select/nice-select.css' );
    wp_enqueue_style( 'nouislider-min', get_template_directory_uri() . '/assets/vendors/nouislider/nouislider.min.css' );
    wp_enqueue_style( 'nouislider-pips-css', get_template_directory_uri() . '/assets/vendors/nouislider/nouislider.pips.css' );
    wp_enqueue_style( 'odometer-min', get_template_directory_uri() . '/assets/vendors/odometer/odometer.min.css' );
    wp_enqueue_style( 'owl-carousel-min', get_template_directory_uri() . '/assets/vendors/owl-carousel/owl.carousel.min.css' );
    wp_enqueue_style( 'owl-carousel-theme-default-min', get_template_directory_uri() . '/assets/vendors/owl-carousel/owl.theme.default.min.css' );
    wp_enqueue_style( 'swiper-min', get_template_directory_uri() . '/assets/vendors/swiper/swiper.min.css' );
    wp_enqueue_style( 'timepicker-css', get_template_directory_uri() . '/assets/vendors/timepicker/timePicker.css' );
    wp_enqueue_style( 'tiny-slider-min', get_template_directory_uri() . '/assets/vendors/tiny-slider/tiny-slider.min.css' );
    wp_enqueue_style( 'vegas-min', get_template_directory_uri() . '/assets/vendors/vegas/vegas.min.css' );
    wp_enqueue_style( 'thm-icons-css', get_template_directory_uri() . '/assets/vendors/thm-icons/style.css' );
    wp_enqueue_style( 'slick-css', get_template_directory_uri() . '/assets/vendors/slick-slider/slick.css' );
    wp_enqueue_style( 'language-switcher-css', get_template_directory_uri() . '/assets/vendors/language-switcher/polyglot-language-switcher.css' );
    wp_enqueue_style( 'reey-font-css', get_template_directory_uri() . '/assets/vendors/reey-font/stylesheet.css' );

	wp_enqueue_style( 'lsicool-main', get_stylesheet_uri() );
	// core
	wp_enqueue_style( 'lsicool-main-style', get_template_directory_uri() .'/assets/css/style.css', array(), time() );
	wp_enqueue_style( 'lsicool-responsive', get_template_directory_uri() .'/assets/css/responsive.css' );


	
    //scripts
	wp_enqueue_script( 'jquery-ui-core');

	wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/vendors/bootstrap/js/bootstrap.bundle.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('bootstrap-select', get_template_directory_uri() . '/assets/vendors/bootstrap-select/js/bootstrap-select.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('bxslider', get_template_directory_uri() . '/assets/vendors/bxslider/jquery.bxslider.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('circleType', get_template_directory_uri() . '/assets/vendors/circleType/jquery.circleType.js', array('jquery'), '1.0', true);
	wp_enqueue_script('lettering', get_template_directory_uri() . '/assets/vendors/circleType/jquery.lettering.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('isotope', get_template_directory_uri() . '/assets/vendors/isotope/isotope.js', array('jquery'), '1.0', true);
	wp_enqueue_script('ajaxchimp', get_template_directory_uri() . '/assets/vendors/jquery-ajaxchimp/jquery.ajaxchimp.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('appear', get_template_directory_uri() . '/assets/vendors/jquery-appear/jquery.appear.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('magnific-popup', get_template_directory_uri() . '/assets/vendors/jquery-magnific-popup/jquery.magnific-popup.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('jquery-migrate', get_template_directory_uri() . '/assets/vendors/jquery-migrate/jquery-migrate.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('jquery-ui', get_template_directory_uri() . '/assets/vendors/jquery-ui/jquery-ui.js', array('jquery'), '1.0', true);
	wp_enqueue_script('jquery-validate', get_template_directory_uri() . '/assets/vendors/jquery-validate/jquery.validate.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('nice-select', get_template_directory_uri() . '/assets/vendors/nice-select/jquery.nice-select.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('nouislider', get_template_directory_uri() . '/assets/vendors/nouislider/nouislider.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('odometer', get_template_directory_uri() . '/assets/vendors/odometer/odometer.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/assets/vendors/owl-carousel/owl.carousel.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('parallax', get_template_directory_uri() . '/assets/vendors/parallax/parallax.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('swiper', get_template_directory_uri() . '/assets/vendors/swiper/swiper.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('timePicker', get_template_directory_uri() . '/assets/vendors/timepicker/timePicker.js', array('jquery'), '1.0', true);
	wp_enqueue_script( 'tiny-slider', get_template_directory_uri() . '/assets/vendors/tiny-slider/tiny-slider.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'typed', get_template_directory_uri() . '/assets/vendors/typed-2.0.11/typed-2.0.11.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'vegas', get_template_directory_uri() . '/assets/vendors/vegas/vegas.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'wNumb', get_template_directory_uri() . '/assets/vendors/wnumb/wNumb.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'wow', get_template_directory_uri() . '/assets/vendors/wow/wow.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'sidebarcontent', get_template_directory_uri() . '/assets/vendors/sidebar-content/jquery-sidebar-content.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'language-switcher', get_template_directory_uri() . '/assets/vendors/language-switcher/jquery.polyglot.language.switcher.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'jarallax', get_template_directory_uri() . '/assets/vendors/jarallax/jarallax.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'slick-slider', get_template_directory_uri() . '/assets/vendors/slick-slider/slick.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'circle-progress', get_template_directory_uri() . '/assets/vendors/jquery-circle-progress/jquery.circle-progress.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'progressbar', get_template_directory_uri() . '/assets/vendors/progress-bar/knob.js', array('jquery'), '1.0', true );



	wp_enqueue_script( 'lsicool-main-script', get_template_directory_uri().'/assets/js/custom.js', array(), false, true );
	if( is_singular() ) wp_enqueue_script('comment-reply');
}
add_action( 'wp_enqueue_scripts', 'lsicool_enqueue_scripts' );



if (class_exists('Redux')) {
	function add_inline_styles() {
		$options = lsicool_WSH()->option();
		if(is_page( 'home-three' )){
			$lsicool_inline_style = ':root {
				--thm-base: ' . $options->get( 'theme_main_color4' ) . ';
				--thm-primary: ' .  $options->get( 'theme_main_color2' ) . ';
				--thm-black: ' .  $options->get( 'theme_main_color3' ) . ';
			}';
		} else {
			$lsicool_inline_style = ':root {
				--thm-base: ' .  $options->get( 'theme_main_color' ) . ';
				--thm-primary: ' .  $options->get( 'theme_main_color2' ) . ';
				--thm-black: ' .  $options->get( 'theme_main_color3' ) . ';
			}';
		}
		wp_add_inline_style( 'lsicool-main-style', $lsicool_inline_style );
	}
	add_action( 'wp_enqueue_scripts', 'add_inline_styles' );
}

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function lsicool_fonts_url() {
	
	$fonts_url = '';
									
		$font_families['Saira Semi Condensed']   = 'Saira Semi Condensed:wght@100,200,300,400,500,600,700,800,900';
		$font_families['Poppins']  		= 'Poppins:wght@300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';


		$font_families = apply_filters( 'lsicool/includes/classes/header_enqueue/font_families', $font_families );

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$protocol  = is_ssl() ? 'https' : 'http';
		$fonts_url = add_query_arg( $query_args, $protocol . '://fonts.googleapis.com/css' );

		return esc_url_raw($fonts_url);

}

function lsicool_theme_styles() {
    wp_enqueue_style( 'lsicool-theme-fonts', lsicool_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'lsicool_theme_styles' );
add_action( 'admin_enqueue_scripts', 'lsicool_theme_styles' );

/*---------- Google fonts ends ----------*/

/*---------- More functions ----------*/

// 1) lsicool_set function

/**
 * [lsicool_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'lsicool_set' ) ) {
	function lsicool_set( $var, $key, $def = '' ) {

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}

// 2) lsicool_add_editor_styles function

function lsicool_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'lsicool_add_editor_styles' );

// 3) Add specific CSS class by filter body class.

$options = lsicool_WSH()->option(); 
if( lsicool_set($options, 'boxed_wrapper') ){

add_filter( 'body_class', function( $classes ) {
    $classes[] = 'boxed_wrapper';
    return $classes;
} );
}

add_filter('doing_it_wrong_trigger_error', function () {return false;}, 10, 0);












function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328647&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        